@@ -22,7 +22,11 @@ class mDastAPI(mDastBase):
         self.headers['Content-Type'] = 'application/json'
         payload = {'username': self.username, 'password': self.password}
 
-        resp = requests.post(f'{self.url}/login/', headers=self.headers, data=json.dumps(payload, indent=4))
+        resp = requests.post(f'{self.url}/login/',
+                             headers=self.headers,
+                             data=json.dumps(payload, indent=4),
+                             verify=False)
+
         resp_body = resp.json()
 
         self.headers['Authorization'] = 'Bearer {0}'.format(resp_body['access'])
@@ -32,15 +36,24 @@ class mDastAPI(mDastBase):
         new_payload = {'username': username, 'password': password}
         self.username = username
         self.password = password
-        resp = requests.post(f'{self.url}/login/', headers=self.headers, data=json.dumps(new_payload, indent=4))
+        resp = requests.post(f'{self.url}/login/',
+                             headers=self.headers,
+                             data=json.dumps(new_payload, indent=4),
+                             verify=False)
+
         if resp.status_code == 200:
             self.set_headers(resp.json()['access'])
-            current_context_resp = requests.get(f'{self.url}/currentuser/', headers=self.headers)
+            current_context_resp = requests.get(f'{self.url}/currentuser/',
+                                                headers=self.headers,
+                                                verify=False)
             self.current_context = current_context_resp.json()
         return resp
 
     def _current_context(self):
-        current_context_resp = requests.get(f'{self.url}/currentuser/', headers=self.headers)
+        current_context_resp = requests.get(f'{self.url}/currentuser/',
+                                            headers=self.headers,
+                                            verify=False)
+
         self.current_context = current_context_resp.json()
 
     def set_headers(self, access_token):
